/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

/**
 * Allows to kill a given JDBC Connection on a datasource
 * @author Florent Benoit
 */
package org.ow2.jonas.admin.jdbcconnections.command {
import com.adobe.cairngorm.commands.ICommand;
import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.control.CairngormEventDispatcher;

import mx.controls.Alert;
import mx.rpc.IResponder;
import mx.rpc.events.ResultEvent;

import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCConnectionsInfosEvent;
import org.ow2.jonas.admin.jdbcconnections.event.GetJDBCDatasourceInfoEvent;
import org.ow2.jonas.admin.jdbcconnections.event.KillAJDBCConnectionEvent;
import org.ow2.kerneos.common.event.KerneosNotificationEvent;


public class KillAJDBCConnectionCommand extends AbsCommand implements ICommand, IResponder {

    public function KillAJDBCConnectionCommand() {
    }

    /**
     * Killing Event
     */
    private var killingConnectionEvent:KillAJDBCConnectionEvent = null;


    /**
     * Execute the action.
     */
    public function execute(event:CairngormEvent):void {
        try {
            // Extract info from the event
            killingConnectionEvent = event as KillAJDBCConnectionEvent;

            delegate.responder = this;
            delegate.killConnection(killingConnectionEvent.objectName, killingConnectionEvent.connectionID);
        } catch (e:Error) {
            Alert.show("error " + e);
            trace("An error occurred: " + e.message);
        }
    }

    /**
     * Manage the result found by a delegate.
     */
    public function result(event:Object):void {
        // value is contained in the event
        var resultEvent:ResultEvent = event as ResultEvent;

        // Change has been done successfully !
        model.dispatch(new KerneosNotificationEvent(KerneosNotificationEvent.KERNEOS_NOTIFICATION, "A connection with ID '" + killingConnectionEvent.connectionID + "' has been closed on a datasource of ObjectName '" + killingConnectionEvent.objectName + "'.", KerneosNotificationEvent.INFO));

        // We have updated the value, needs to refresh the connections
        var configEvent:GetJDBCConnectionsInfosEvent = new GetJDBCConnectionsInfosEvent(GetJDBCConnectionsInfosEvent.EVENT_GET_JDBC_CONNECTIONS_INFO, model.selectedJDBCDatasourceObjectName, 0);
        dispatcher.dispatchEvent(configEvent);

        // And the datasource configuration
        var datasourceEvent:GetJDBCDatasourceInfoEvent = new GetJDBCDatasourceInfoEvent(GetJDBCDatasourceInfoEvent.EVENT_GET_JDBC_DATASOURCE_INFO, model.selectedJDBCDatasourceObjectName);
        dispatcher.dispatchEvent(datasourceEvent);

    }


}
}