/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009-2012 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

package org.ow2.jonas.admin.jdbcconnections.model {

import com.adobe.cairngorm.control.CairngormEvent;
import com.adobe.cairngorm.model.ModelLocator;

import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.jdbcconnections.business.MyDelegate;

import org.ow2.jonas.admin.jdbcconnections.view.JDBCConnectionsView;
import org.ow2.jonas.admin.jdbcconnections.vo.JDBCDatasourceInfoVO;
import org.ow2.jonas.admin.jdbcconnections.vo.JNDIInterceptorsConfigurationVO;


/**
 * Cairngorm Model Locator for the JDBC Connections module
 * @author Florent Benoit
 */
[Bindable]
public class JDBCConnectionsModelLocator implements ModelLocator {


    /**
     * Link to the view.
     */
    private var jdbcConnectionsView : JDBCConnectionsView = null;

    /**
     * JNDI Interceptors configuration.
     */
    private var jndiInterceptorsConfigurationVO : JNDIInterceptorsConfigurationVO = null;

	/**
	 * JDBC Datasource info
	 */
	 private  var datasourceInfoVO : JDBCDatasourceInfoVO = null;


    /**
     * Information on all the active JDBC Connections of the selected datasource.
     */
    [ArrayElementType(JDBCConnectionInfoVO)]
    public var activeJDBCConnectionsInfoArrayCollectionVO : ArrayCollection;
	 
    /**
     * Displays advanced columns for the JDBC Connections infos.
     */
    private var showAdvancedJDBCConnectionsInfoValue : Boolean = false;


    /**
     * Xml data of the datasources (all JDBC Datasources available on the remote side).
     */
    private var availableJdbcDatasources : XML = null;


    /**
     * Value of the selected Datasource ObjectName.
     */
    private var selectedJDBCDatasourceObjectNameText : String;


    /**
     * The datasources needs to be refreshed by the timer.
     */
    private var refreshListDatasourcesValue : Boolean = true;

    /**
     * The datasource info needs to be refreshed by the timer.
     */
    private var refreshDatasourceInfoValue : Boolean = true;

    /**
     * The JDBC Connection info needs to be refreshed by the timer.
     */
    private var refreshJdbcConnectionsInfoValue : Boolean = true;


    /**
     * Constructor
     */
    public function JDBCConnectionsModelLocator() {
    }

    /**
     * unique instance of delegate
     */
    private var _delegate:MyDelegate = null;

    public function getDelegate():MyDelegate {
        if (_delegate == null) {
            _delegate = new MyDelegate();
        }
        return _delegate;
    }

    public function get jndiInterceptorsConfiguration() : JNDIInterceptorsConfigurationVO {
        return jndiInterceptorsConfigurationVO;
    }


    public function set jndiInterceptorsConfiguration(jndiInterceptorsConfigurationVO : JNDIInterceptorsConfigurationVO) : void {
        this.jndiInterceptorsConfigurationVO = jndiInterceptorsConfigurationVO;
    }



    public function get jdbcDatasources() : XML {
        return availableJdbcDatasources;
    }


    public function set jdbcDatasources(availableJdbcDatasources : XML) : void {
        this.availableJdbcDatasources = availableJdbcDatasources;
    }



    

    public function set view(jdbcConnectionsView : JDBCConnectionsView) : void {
        this.jdbcConnectionsView = jdbcConnectionsView;
    }

    public function dispatch(event : CairngormEvent) : void {
        jdbcConnectionsView.dispatchEvent(event);

    }


    public function set datasourceInfo(datasourceInfoVO : JDBCDatasourceInfoVO) : void {
        this.datasourceInfoVO = datasourceInfoVO;
    }
    
    public function get datasourceInfo() : JDBCDatasourceInfoVO {
        return datasourceInfoVO;
    }
    

    public function get selectedJDBCDatasourceObjectName() : String {
        return selectedJDBCDatasourceObjectNameText;
    }


    public function set selectedJDBCDatasourceObjectName(selectedJDBCDatasourceObjectNameText : String) : void {
        this.selectedJDBCDatasourceObjectNameText = selectedJDBCDatasourceObjectNameText;
    }

	public function get showAdvancedJDBCConnectionsInfo() : Boolean {
		return showAdvancedJDBCConnectionsInfoValue;
	}

	public function set showAdvancedJDBCConnectionsInfo(showAdvancedJDBCConnectionsInfoValue : Boolean) : void {
		this.showAdvancedJDBCConnectionsInfoValue = showAdvancedJDBCConnectionsInfoValue;
	}
	
	public function get refreshListDatasources() : Boolean {
		return refreshListDatasourcesValue;
	}

	public function set refreshListDatasources(refreshListDatasourcesValue : Boolean) : void {
		this.refreshListDatasourcesValue = refreshListDatasourcesValue;
	}
	
		
	public function get refreshDatasourceInfo() : Boolean {
		return refreshDatasourceInfoValue;
	}

	public function set refreshDatasourceInfo(refreshDatasourceInfoValue : Boolean) : void {
		this.refreshDatasourceInfoValue = refreshDatasourceInfoValue;
	}
	
		
	public function get refreshJdbcConnectionsInfo() : Boolean {
		return refreshJdbcConnectionsInfoValue;
	}

	public function set refreshJdbcConnectionsInfo(refreshJdbcConnectionsInfoValue : Boolean) : void {
		this.refreshJdbcConnectionsInfoValue = refreshJdbcConnectionsInfoValue;
	}


}
}
